@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2013 The XCSoar Project
+  Copyright (C) 2000-2014 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -22,6 +22,7 @@ Copyright_License {
 */
 
 #include "Queue.hpp"
+#include "DisplayOrientation.hpp"
 #include "OS/Clock.hpp"
 
 EventQueue::EventQueue()
@@ -69,32 +70,30 @@ EventQueue::~EventQueue()
 }
 
 #ifndef NON_INTERACTIVE
-#ifdef KOBO
 
 void
-EventQueue::SetMouseRotation(DisplaySettings::Orientation orientation)
+EventQueue::SetMouseRotation(DisplayOrientation orientation)
 {
   switch (orientation) {
-  case DisplaySettings::Orientation::DEFAULT:
-  case DisplaySettings::Orientation::PORTRAIT:
+  case DisplayOrientation::DEFAULT:
+  case DisplayOrientation::PORTRAIT:
     SetMouseRotation(true, true, false);
     break;
 
-  case DisplaySettings::Orientation::LANDSCAPE:
+  case DisplayOrientation::LANDSCAPE:
     SetMouseRotation(false, false, false);
     break;
 
-  case DisplaySettings::Orientation::REVERSE_PORTRAIT:
+  case DisplayOrientation::REVERSE_PORTRAIT:
     SetMouseRotation(true, false, true);
     break;
 
-  case DisplaySettings::Orientation::REVERSE_LANDSCAPE:
+  case DisplayOrientation::REVERSE_LANDSCAPE:
     SetMouseRotation(false, true, true);
     break;
   }
 }
 
-#endif
 #endif
 
 void
